@@ -1,14 +1,13 @@
 import hashlib
 from fabric.api import *
 from ground_soil.filesystem import rsync
-from beanstalk.decorators import beanstalk_role
+from beanstalk.decorators import beanstalk_task
 from beanstalk.tasks.utils import load_role_settings, load_web_servers
 from beanstalk.console.titles import tool_title
 from beanstalk.validator import validate_file_existence
 
 
-@task
-@beanstalk_role('app')
+@beanstalk_task(beanstalk_role='app')
 def add(settings_path=None, **settings_patches):
     """Add current user to beanstalk-stack server
     """
